@@ -29,7 +29,7 @@ print '-=' x 20 . "\n\n";
 
 print "\n" . '-=' x 20 . "\n";
 print "NOMINAL LOAD & MATCH TEST\n";
-print "- 2 datasets of 100 samples each have been generated\n";
+print "- 2 datasets of 100 samplings each have been generated\n";
 print "- they each contain an independent sampling of one of 5 alternative states\n";
 print "- they will now be matched for the synchrony of their states at each sampling event:\n";
 print "\n";
